@@ -101,15 +101,15 @@ typedef struct _match
 static char *previous_sm_client_id = NULL;
 static char *sm_client_id = NULL;
 static Bool sent_save_done = 0;
-static char *realStateFilename = NULL;
-static Bool goingToRestart = False;
+static char *real_state_filename = NULL;
+static Bool going_to_restart = False;
 static FIceIOErrorHandler prev_handler;
 static FSmcConn sm_conn = NULL;
 
 static int num_match = 0;
 static Match *matches = NULL;
 static Bool does_file_version_match = False;
-static Bool doPreserveState = True;
+static Bool do_preserve_state = True;
 
 /* ---------------------------- exported variables (globals) --------------- */
 
@@ -176,35 +176,34 @@ SaveGlobalState(FILE *f)
 	fprintf(f, "  [DESKTOP] %i\n", Scr.CurrentDesk);
 	fprintf(f, "  [VIEWPORT] %i %i %i %i\n",
 		Scr.Vx, Scr.Vy, Scr.VxMax, Scr.VyMax);
-	fprintf(f, "  [SCROLL] %i %i %i %i %i %i\n",
-		Scr.EdgeScrollX, Scr.EdgeScrollY, Scr.ScrollResistance,
-		Scr.MoveResistance,
+	fprintf(f, "  [SCROLL] %i %i %i %i %i\n",
+		Scr.EdgeScrollX, Scr.EdgeScrollY, Scr.ScrollDelay,
 		!!(Scr.flags.do_edge_wrap_x), !!(Scr.flags.do_edge_wrap_y));
-	fprintf(f, "  [SNAP] %i %i %i %i\n",
-		Scr.SnapAttraction, Scr.SnapMode, Scr.SnapGridX, Scr.SnapGridY);
 	fprintf(f, "  [MISC] %i %i %i\n",
 		Scr.ClickTime, Scr.ColormapFocus, Scr.ColorLimit);
-	fprintf(f, "  [STYLE] %i %i\n", Scr.gs.do_emulate_mwm, Scr.gs.do_emulate_win);
+	fprintf(
+		f, "  [STYLE] %i %i\n", Scr.gs.do_emulate_mwm,
+		Scr.gs.do_emulate_win);
 
 	return 1;
 }
 
-static void setRealStateFilename(char *filename)
+static void set_real_state_filename(char *filename)
 {
 	if (!SessionSupport)
 	{
 		return;
 	}
-	if (realStateFilename)
+	if (real_state_filename)
 	{
-		free(realStateFilename);
+		free(real_state_filename);
 	}
-	realStateFilename = safestrdup(filename);
+	real_state_filename = safestrdup(filename);
 
 	return;
 }
 
-static char *getUniqueStateFilename(void)
+static char *get_unique_state_filename(void)
 {
 	const char *path = getenv("SM_SAVE_DIR");
 	char *filename;
@@ -438,6 +437,14 @@ SaveWindowStates(FILE *f)
 				/* No client id and no WM_COMMAND, the client
 				 * cannot be managed by the sessiom manager
 				 * skip it! */
+				/* TA:  20110611 - But actually, this breaks
+				 * those applications which don't set the
+				 * WM_COMMAND XAtom anymore.  The ICCCM
+				 * deprecated this at version 2.0 -- and its
+				 * lack of existence here shouldn't be a
+				 * problem.  Let newer session managers handle
+				 * the error if it even matters.
+				 */
 				if (!Restarting)
 				{
 					if (wm_command)
@@ -445,7 +452,11 @@ SaveWindowStates(FILE *f)
 						XFreeStringList(wm_command);
 						wm_command = NULL;
 					}
-					continue;
+					/* TA: 20110611 - But see above.  We
+					 * no longer skip clients who don't
+					 * set this legacy field.
+					 */
+					/* continue; */
 				}
 			}
 		}
@@ -683,7 +694,7 @@ static Bool matchWin(FvwmWindow *w, Match *m)
 	return found;
 }
 
-static int saveStateFile(char *filename)
+static int save_state_file(char *filename)
 {
 	FILE *f;
 	int success;
@@ -702,16 +713,16 @@ static int saveStateFile(char *filename)
 	fprintf(f, "# Normally, you must never delete this file,"
 		" it will be auto-deleted.\n\n");
 
-	if (SessionSupport && goingToRestart)
+	if (SessionSupport && going_to_restart)
 	{
-		fprintf(f, "[REAL_STATE_FILENAME] %s\n", realStateFilename);
-		goingToRestart = False;  /* not needed */
+		fprintf(f, "[REAL_STATE_FILENAME] %s\n", real_state_filename);
+		going_to_restart = False;  /* not needed */
 	}
 
-	success = doPreserveState?
-		SaveVersionInfo(f) && SaveWindowStates(f) && SaveGlobalState(f):
-		1;
-	doPreserveState = True;
+	success = do_preserve_state
+		? SaveVersionInfo(f) && SaveWindowStates(f) && SaveGlobalState(f)
+		: 1;
+	do_preserve_state = True;
 	if (fclose(f) != 0)
 		return 0;
 
@@ -728,7 +739,7 @@ static int saveStateFile(char *filename)
 }
 
 static void
-setSmProperties(FSmcConn sm_conn, char *filename, char hint)
+set_sm_properties(FSmcConn sm_conn, char *filename, char hint)
 {
 	FSmProp prop1, prop2, prop3, prop4, prop5, prop6, prop7, *props[7];
 	FSmPropValue prop1val, prop2val, prop3val, prop4val, prop7val;
@@ -736,7 +747,7 @@ setSmProperties(FSmcConn sm_conn, char *filename, char hint)
 	char *user_id;
 	char screen_num[32];
 	int numVals, i, priority = 30;
-	Bool xsmDetected = False;
+	Bool is_xsm_detected = False;
 
 	if (!SessionSupport)
 	{
@@ -744,8 +755,8 @@ setSmProperties(FSmcConn sm_conn, char *filename, char hint)
 	}
 
 #ifdef FVWM_SM_DEBUG_PROTO
-	fprintf(stderr, "[FVWM_SMDEBUG][setSmProperties] state filename: %s%s\n",
-		(filename)? filename:"(null)", sm_conn? "": " - not connected");
+	fprintf(stderr, "[FVWM_SMDEBUG][set_sm_properties] state filename: %s%s\n",
+		filename ? filename : "(null)", sm_conn ? "" : " - not connected");
 #endif
 
 	if (!sm_conn)
@@ -867,9 +878,9 @@ setSmProperties(FSmcConn sm_conn, char *filename, char hint)
 
 		prop7.name = FSmDiscardCommand;
 
-		xsmDetected = StrEquals(getenv("SESSION_MANAGER_NAME"), "xsm");
+		is_xsm_detected = StrEquals(getenv("SESSION_MANAGER_NAME"), "xsm");
 
-		if (xsmDetected)
+		if (is_xsm_detected)
 		{
 			/* the protocol spec says that the discard command
 			   should be LISTofARRAY8 on posix systems, but xsm
@@ -913,7 +924,7 @@ setSmProperties(FSmcConn sm_conn, char *filename, char hint)
 		FSmcSetProperties (sm_conn, 7, props);
 
 		free ((char *) prop6.vals);
-		if (!xsmDetected)
+		if (!is_xsm_detected)
 		{
 			free ((char *) prop7.vals);
 		}
@@ -937,16 +948,16 @@ callback_save_yourself2(FSmcConn sm_conn, FSmPointer client_data)
 		return;
 	}
 
-	filename = getUniqueStateFilename();
+	filename = get_unique_state_filename();
 #ifdef FVWM_SM_DEBUG_PROTO
 	fprintf(stderr, "[FVWM_SMDEBUG][callback_save_yourself2]\n");
 #endif
 
-	success = saveStateFile(filename);
+	success = save_state_file(filename);
 	if (success)
 	{
-		setSmProperties(sm_conn, filename, FSmRestartIfRunning);
-		setRealStateFilename(filename);
+		set_sm_properties(sm_conn, filename, FSmRestartIfRunning);
+		set_real_state_filename(filename);
 	}
 	free(filename);
 
@@ -1113,7 +1124,7 @@ LoadGlobalState(char *filename)
 	FILE *f;
 	char s[4096], s1[4096];
 	/* char s2[256]; */
-	int i1, i2, i3, i4, i5, i6;
+	int i1, i2, i3, i4;
 
 	if (!does_file_version_match)
 	{
@@ -1130,7 +1141,10 @@ LoadGlobalState(char *filename)
 
 	while (fgets(s, sizeof(s), f))
 	{
-		i1 = 0; i2 = 0; i3 = 0; i4 = 0; i5 = 0; i6 = 0;
+		i1 = 0;
+		i2 = 0;
+		i3 = 0;
+		i4 = 0;
 		sscanf(s, "%4000s", s1);
 		/* If we are restarting, [REAL_STATE_FILENAME] points
 		 * to the file containing the true session state. */
@@ -1139,8 +1153,8 @@ LoadGlobalState(char *filename)
 			/* migo: temporarily (?) moved to
 			   LoadWindowStates (trick for gnome-session)
 			   sscanf(s, "%*s %s", s2);
-			   setFSmProperties (sm_conn, s2, FSmRestartIfRunning);
-			   setRealStateFilename(s2);
+			   set_sm_properties(sm_conn, s2, FSmRestartIfRunning);
+			   set_real_state_filename(s2);
 			*/
 		}
 		else if (!strcmp(s1, "[DESKTOP]"))
@@ -1170,13 +1184,12 @@ LoadGlobalState(char *filename)
 			 * changed rc files. */
 			if (!strcmp(s1, "[SCROLL]"))
 			{
-				sscanf(s, "%*s %i %i %i %i %i %i", &i1,
-				       &i2, &i3, &i4, &i5, &i6);
+				sscanf(s, "%*s %i %i %i %i ", &i1,
+				       &i2, &i3, &i4);
 				Scr.EdgeScrollX = i1;
 				Scr.EdgeScrollY = i2;
-				Scr.ScrollResistance = i3;
-				Scr.MoveResistance = i4;
-				if (i5)
+				Scr.ScrollDelay = i3;
+				if (i4)
 				{
 					Scr.flags.edge_wrap_x = 1;
 				}
@@ -1184,7 +1197,7 @@ LoadGlobalState(char *filename)
 				{
 					Scr.flags.edge_wrap_x = 0;
 				}
-				if (i6)
+				if (i3)
 				{
 					Scr.flags.edge_wrap_y = 1;
 				}
@@ -1193,15 +1206,6 @@ LoadGlobalState(char *filename)
 					Scr.flags.edge_wrap_y = 0;
 				}
 			}
-			else if (!strcmp(s1, "[SNAP]"))
-			{
-				sscanf(s, "%*s %i %i %i %i", &i1, &i2,
-				       &i3, &i4);
-				Scr.SnapAttraction = i1;
-				Scr.SnapMode = i2;
-				Scr.SnapGridX = i3;
-				Scr.SnapGridY = i4;
-			}
 			else if (!strcmp(s1, "[MISC]"))
 			{
 				sscanf(s, "%*s %i %i %i", &i1, &i2,
@@ -1250,7 +1254,7 @@ LoadWindowStates(char *filename)
 	{
 		return;
 	}
-	setRealStateFilename(filename);
+	set_real_state_filename(filename);
 	if ((f = fopen(filename, "r")) == NULL)
 	{
 		return;
@@ -1273,8 +1277,8 @@ LoadWindowStates(char *filename)
 		    !strcmp(s1, "[REAL_STATE_FILENAME]"))
 		{
 			sscanf(s, "%*s %s", s1);
-			setSmProperties (sm_conn, s1, FSmRestartIfRunning);
-			setRealStateFilename(s1);
+			set_sm_properties(sm_conn, s1, FSmRestartIfRunning);
+			set_real_state_filename(s1);
 		}
 		else if (!strcmp(s1, "[CLIENT]"))
 		{
@@ -1568,9 +1572,6 @@ MatchWinToSM(
 			ewin->ewmh_hint_desktop = matches[i].ewmh_hint_desktop;
 			SET_HAS_EWMH_INIT_WM_DESKTOP(
 				ewin, HAS_EWMH_INIT_WM_DESKTOP(&(matches[i])));
-			SET_HAS_EWMH_INIT_FULLSCREEN_STATE(
-				ewin, HAS_EWMH_INIT_FULLSCREEN_STATE(
-					&(matches[i])));
 			SET_HAS_EWMH_INIT_HIDDEN_STATE(
 				ewin, HAS_EWMH_INIT_HIDDEN_STATE(
 					&(matches[i])));
@@ -1594,16 +1595,16 @@ MatchWinToSM(
 }
 
 void
-RestartInSession (char *filename, Bool isNative, Bool _doPreserveState)
+RestartInSession (char *filename, Bool is_native, Bool _do_preserve_state)
 {
-	doPreserveState = _doPreserveState;
+	do_preserve_state = _do_preserve_state;
 
-	if (SessionSupport && sm_conn && isNative)
+	if (SessionSupport && sm_conn && is_native)
 	{
-		goingToRestart = True;
+		going_to_restart = True;
 
-		saveStateFile(filename);
-		setSmProperties(sm_conn, filename, FSmRestartImmediately);
+		save_state_file(filename);
+		set_sm_properties(sm_conn, filename, FSmRestartImmediately);
 
 		MoveViewport(0, 0, False);
 		Reborder();
@@ -1626,7 +1627,7 @@ RestartInSession (char *filename, Bool isNative, Bool _doPreserveState)
 		exit(0); /* let the SM restart us */
 	}
 
-	saveStateFile(filename);
+	save_state_file(filename);
 	/* return and let Done restart us */
 
 	return;
@@ -1698,12 +1699,12 @@ SessionInit(void)
 #ifdef FVWM_SM_DEBUG_PROTO
 		fprintf(stderr,"[FVWM_SMDEBUG] Connectecd to a SM\n");
 #endif
-		setInitFunctionName(0, "SessionInitFunction");
-		setInitFunctionName(1, "SessionRestartFunction");
-		setInitFunctionName(2, "SessionExitFunction");
+		set_init_function_name(0, "SessionInitFunction");
+		set_init_function_name(1, "SessionRestartFunction");
+		set_init_function_name(2, "SessionExitFunction");
 		/* basically to restet our restart style hint after a
 		 * restart */
-		setSmProperties(sm_conn, NULL, FSmRestartIfRunning);
+		set_sm_properties(sm_conn, NULL, FSmRestartIfRunning);
 	}
 
 	return;
@@ -1745,42 +1746,42 @@ ProcessICEMsgs(void)
  * Alternative implementation may use unix signals, but this does not work
  * with all session managers (also must suppose that SM runs locally).
  */
-int getSmPid(void)
+int get_sm_pid(void)
 {
-	const char *sessionManagerVar = getenv("SESSION_MANAGER");
-	const char *smPidStrPtr;
-	int smPid = 0;
+	const char *session_manager_var = getenv("SESSION_MANAGER");
+	const char *sm_pid_str_ptr;
+	int sm_pid = 0;
 
 	if (!SessionSupport)
 	{
 		return 0;
 	}
 
-	if (!sessionManagerVar)
+	if (!session_manager_var)
 	{
 		return 0;
 	}
-	smPidStrPtr = strchr(sessionManagerVar, ',');
-	if (!smPidStrPtr)
+	sm_pid_str_ptr = strchr(session_manager_var, ',');
+	if (!sm_pid_str_ptr)
 	{
 		return 0;
 	}
-	while (smPidStrPtr > sessionManagerVar && isdigit(*(--smPidStrPtr)))
+	while (sm_pid_str_ptr > session_manager_var && isdigit(*(--sm_pid_str_ptr)))
 	{
 		/* nothing */
 	}
-	while (isdigit(*(++smPidStrPtr)))
+	while (isdigit(*(++sm_pid_str_ptr)))
 	{
-		smPid = smPid * 10 + *smPidStrPtr - '0';
+		sm_pid = sm_pid * 10 + *sm_pid_str_ptr - '0';
 	}
 
-	return smPid;
+	return sm_pid;
 }
 
 /*
- * quitSession - hopefully shutdowns the session
+ * quit_session - hopefully shutdowns the session
  */
-Bool quitSession(void)
+Bool quit_session(void)
 {
 	if (!SessionSupport)
 	{
@@ -1799,16 +1800,16 @@ Bool quitSession(void)
 	/* migo: xsm does not support RequestSaveYourself, but supports
 	 * signals: */
 	/*
-	  int smPid = getSmPid();
-	  if (!smPid) return False;
-	  return kill(smPid, SIGTERM) == 0? True: False;
+	  int sm_pid = get_sm_pid();
+	  if (!sm_pid) return False;
+	  return kill(sm_pid, SIGTERM) == 0 ? True : False;
 	*/
 }
 
 /*
- * saveSession - hopefully saves the session
+ * save_session - hopefully saves the session
  */
-Bool saveSession(void)
+Bool save_session(void)
 {
 	if (!SessionSupport)
 	{
@@ -1827,16 +1828,16 @@ Bool saveSession(void)
 	/* migo: xsm does not support RequestSaveYourself, but supports
 	 * signals: */
 	/*
-	  int smPid = getSmPid();
-	  if (!smPid) return False;
-	  return kill(smPid, SIGUSR1) == 0? True: False;
+	  int sm_pid = get_sm_pid();
+	  if (!sm_pid) return False;
+	  return kill(sm_pid, SIGUSR1) == 0 ? True : False;
 	*/
 }
 
 /*
- * saveQuitSession - hopefully saves and shutdowns the session
+ * save_quit_session - hopefully saves and shutdowns the session
  */
-Bool saveQuitSession(void)
+Bool save_quit_session(void)
 {
 	if (!SessionSupport)
 	{
@@ -1856,9 +1857,9 @@ Bool saveQuitSession(void)
 	/* migo: xsm does not support RequestSaveYourself, but supports
 	 * signals: */
 	/*
-	  if (saveSession() == False) return False;
+	  if (save_session() == False) return False;
 	  sleep(3);  / * doesn't work anyway * /
-	  if (quitSession() == False) return False;
+	  if (quit_session() == False) return False;
 	  return True;
 	*/
 }
@@ -1867,21 +1868,21 @@ Bool saveQuitSession(void)
 
 void CMD_QuitSession(F_CMD_ARGS)
 {
-	quitSession();
+	quit_session();
 
 	return;
 }
 
 void CMD_SaveSession(F_CMD_ARGS)
 {
-	saveSession();
+	save_session();
 
 	return;
 }
 
 void CMD_SaveQuitSession(F_CMD_ARGS)
 {
-	saveQuitSession();
+	save_quit_session();
 
 	return;
 }
